@@ -33,7 +33,18 @@ end
 -- dir must be a subdir of spec/ containing expected.out or expected_file.
 -- The file can contain 'X' to match any number of hits.
 -- flags will be passed to luacov.
-local function assert_cli(dir, enable_cluacov, expected_file, flags)
+local function assert_cli(dir, enable_cluacov, expected_file, flags, configfp)
+
+   local prefix = ""
+   local postfix = ""
+
+   if configfp and dir_sep == "\\" then
+     prefix = ("set \"LUACOV_CONFIG=%s\" &&"):format(configfp)
+     postfix = ("& set LUACOV_CONFIG=")
+   elseif configfp then
+     prefix = ("LUACOV_CONFIG=%q"):format(configfp)
+   end
+
    local test_dir = "spec" .. dir_sep .. dir
    local _, nestingLevel = dir:gsub("/", "")
 
@@ -56,10 +67,10 @@ local function assert_cli(dir, enable_cluacov, expected_file, flags)
       init_lua = init_lua .. "; package.preload[ [[cluacov.version]] ] = error"
    end
 
-   exec(("cd %q && %q -e %q -lluacov test.lua %s"):format(test_dir, lua, init_lua, flags))
+   exec(("cd %q && %s %q -e %q -lluacov test.lua %s %s"):format(test_dir, prefix, lua, init_lua, flags, postfix))
 
    local luacov_path = (src_path .. "/bin/luacov"):gsub("/", dir_sep)
-   exec(("cd %q && %q -e %q %s %s"):format(test_dir, lua, init_lua, luacov_path, flags))
+   exec(("cd %q && %s %q -e %q %s %s %s"):format(test_dir, prefix, lua, init_lua, luacov_path, flags, postfix))
 
    expected_file = test_dir .. dir_sep .. expected_file
    local expected = read_file(expected_file)
@@ -127,6 +138,11 @@ local function register_cli_tests(enable_cluacov)
             assert_cli("cluacov", enable_cluacov)
          end)
       end
+
+      it("handles configs specified via LUACOV_CONFIG", function()
+         assert_cli("LUACOV_CONFIG", enable_cluacov, nil, nil, "luacov.config.lua")
+      end)
+
    end)
 end
 
