@@ -6,7 +6,7 @@
 
 local runner = {}
 --- LuaCov version in `MAJOR.MINOR.PATCH` format.
-runner.version = "0.15.0"
+runner.version = "0.16.0"
 
 local stats = require("luacov.stats")
 local util = require("luacov.util")
@@ -141,6 +141,8 @@ local function on_exit()
    -- so this method could be called twice
    if on_exit_run_once then return end
    on_exit_run_once = true
+   -- disable hooks before aggregating stats
+   debug.sethook(nil)
    runner.save_stats()
 
    if runner.configuration.runreport then
@@ -378,7 +380,7 @@ local function load_config_file(name, is_default)
    raw_os_exit(1)
 end
 
-local default_config_file = ".luacov"
+local default_config_file = os.getenv("LUACOV_CONFIG") or ".luacov"
 
 ------------------------------------------------------
 -- Loads a valid configuration.
